pub struct NoteID { /* private fields */ }Expand description
Represents an identifier for a note
This is an opaque identifier that can be used to refer to a specific note that is playing.
Implementations